@@ -4,6 +4,8 @@ gpcmodel <- function(y, weights = NULL, impact = NULL,
   type = c("GPCM", "PCM"), grouppars = FALSE, vcov = TRUE, nullcats = "downcode",
   start = NULL, method = "BFGS", maxit = 500L, reltol = 1e-5, ...)
 {
+  ## original function call
+  mcall <- match.call()
 
   ## check for mirt
   if(!requireNamespace("mirt", quietly = TRUE)) {
@@ -277,12 +279,13 @@ gpcmodel <- function(y, weights = NULL, impact = NULL,
     loglik = mirt::extract.mirt(model, "logLik"),
     df = mirt::extract.mirt(model, "nest"),
     code = code,
-    iterations = structure(mirt::extract.mirt(model, "iterations"), names = "gradient"),
+    iterations = structure(mirt::extract.mirt(model, "iterations"), names = "EM cycles"),
     reltol = reltol,
     method = method,
     grouppars = grouppars,
     type = type,
-    mirt = model
+    mirt = model,
+    call = mcall
   )
   class(res) <- "gpcmodel"
   return(res)
@@ -357,7 +360,8 @@ summary.gpcmodel <- function(object, vcov. = NULL, ...)
 print.summary.gpcmodel <- function(x, digits = max(3L, getOption("digits") - 3L),
   signif.stars = getOption("show.signif.stars"), ...)
 {
-  if(is.null(x$call)) {
+  show_call <- FALSE
+  if (is.null(x$call) || !show_call) {
     cat(sprintf("\n%s\n\n",
       if(x$type == "PCM") "Partial credit model" else "Generalized partial credit model"))
   } else {
@@ -374,7 +378,8 @@ print.summary.gpcmodel <- function(x, digits = max(3L, getOption("digits") - 3L)
     na.print = "NA", ...)
   cat("\nLog-likelihood:", format(signif(x$loglik, digits)),
     "(df =", paste(x$df, ")", sep = ""), "\n")
-  cat(sprintf("Number of iterations in %s optimization: %s\n\n", x$method, x$iterations))
+  cat(sprintf("Number of EM cycles: %s\n", x$iterations))
+  cat(sprintf("M-step optimizer: %s\n", x$method))
   invisible(x)
 }
 
@@ -1209,7 +1214,7 @@ pgpcm <- function(theta = NULL, a = NULL, b = NULL)
 {
   ## probabilities under the model (in IRT formulation) given theta
   stopifnot(!is.null(theta) & !is.null(a) & !is.null(b))
-  stopifnot(typeof(a) == typeof(b))
+  stopifnot(mode(a) == mode(b))
   if(is.list(theta)) {
     return(lapply(theta, pgpcm, a = a, b = b))
   }
@@ -1225,12 +1230,10 @@ pgpcm <- function(theta = NULL, a = NULL, b = NULL)
 
 
 
-rgpcm <- function(theta = NULL, a = NULL, b = NULL, nullcats = FALSE,
-  return_setting = TRUE)
+rgpcm <- function(theta, a, b, nullcats = FALSE, return_setting = TRUE)
 {
   ## sample data under the model (in IRT formulation) given theta
-  stopifnot(!is.null(theta) & !is.null(a) & !is.null(b))
-  stopifnot(typeof(a) == typeof(b))
+  stopifnot(mode(a) == mode(b))
   if(is.list(theta)) {
     return(lapply(theta, rgpcm, a = a, b = b, nullcats = nullcats,
       return_setting = return_setting))
