@@ -3,6 +3,8 @@ raschmodel <- function(y, weights = NULL, start = NULL, reltol = 1e-10,
   deriv = c("sum", "diff", "numeric"), hessian = TRUE, maxit = 100L,
   full = TRUE, gradtol = reltol, iterlim = maxit, ...)
 {
+  ## original function call
+  mcall <- if(full) match.call() else NULL
 
   ## argument matching
   if(missing(reltol) && !missing(gradtol) && !is.null(gradtol)) reltol <- gradtol
@@ -252,9 +254,14 @@ raschmodel <- function(y, weights = NULL, start = NULL, reltol = 1e-10,
     if(hessian) {
       vc <- if(deriv == "numeric") opt$hessian else ahessian(cf, esf)
       ## FIXME: how to invert
-      vc <- chol2inv(chol(vc))
-      #vc <- qr.solve(vc)
-    } else {
+      ## #vc <- qr.solve(vc)
+      vc <- try(chol2inv(chol(vc)), silent = TRUE)
+      if (inherits(vc, "try-error")) {
+        hessian <- FALSE
+        warning("could not invert Hessian, setting variance-covariance matrix to NA")
+      }
+    }
+    if (!hessian) {
       vc <- matrix(NA, nrow = length(cf), ncol = length(cf))
     }
     rownames(vc) <- colnames(vc) <- names(cf)
@@ -278,7 +285,8 @@ raschmodel <- function(y, weights = NULL, start = NULL, reltol = 1e-10,
     code = opt$convergence,
     iterations = tail(na.omit(opt$counts), 1L),
     reltol = reltol,
-    deriv = deriv        
+    deriv = deriv,
+    call = mcall
   )
   class(rval) <- "raschmodel"
   return(rval)
@@ -334,7 +342,8 @@ summary.raschmodel <- function(object, vcov. = NULL, ...)
 print.summary.raschmodel <- function(x, digits = max(3, getOption("digits") - 3), 
     signif.stars = getOption("show.signif.stars"), ...)
 {
-  if(is.null(x$call)) {
+  show_call <- FALSE
+  if (is.null(x$call) || !show_call) {
     cat("\nRasch model\n\n")  
   } else {
     cat("\nCall:\n")
@@ -666,8 +675,8 @@ personpar.raschmodel <- function(object, personwise = FALSE, ref = NULL,
       rf <- rf[rf != 0]
       # obtain Hessian from objective function: joint log likelihood
       cloglik <- function(pp) {
-        - sum(rf * rng * pp) + sum(cs * ip) +
-        sum(rf * rowSums(log(1 + exp(outer(pp, ip, "-")))))
+        - sum(rng * pp) + sum(cs * ip) +
+        sum(rowSums(log(1 + exp(outer(pp, ip, "-")))))
       }
       vc <- solve(optim(pp, fn = cloglik, hessian = TRUE, method = "BFGS",
         control = list(reltol = tol, maxit = 0, ...))$hessian)
@@ -800,11 +809,8 @@ prm <- function(theta = NULL, beta = NULL)
 }
 
 ## rrm: calculate response matrices for given thetas and betas under the RM.
-rrm <- function(theta = NULL, beta = NULL, return_setting = TRUE)
+rrm <- function(theta, beta, return_setting = TRUE)
 {
-  ## check input
-  stopifnot(!is.null(theta) && !is.null(beta))
-  
   ## if list input, recurse...
   if (is.list(theta)) return(lapply(theta, rrm, beta = beta, return_setting = return_setting))
   if (is.list(beta)) return(lapply(beta, rrm, theta = theta, return_setting = return_setting))
